@@ -73,9 +73,12 @@ class BaseTask(object):
         self.coroutine_future = future
 
     def cancel(self):
+        self.remove()
+        self.coroutine_future.cancel()
+
+    def remove(self):
         self.app.tasks.remove(self)
         self.processor.tasks.remove(self)
-        self.coroutine_future.cancel()
 
     def set_app(self, atp):
         """
@@ -106,4 +109,4 @@ class BaseTask(object):
         return str(self.as_dict())
 
     def as_json(self):
-        return json.dumps(self.as_dict())
+        return json.dumps(self.as_dict())
\ No newline at end of file
