@@ -50,6 +50,9 @@ class SimpleProcessor(BaseProcessor):
         :return:
         """
         while True:
+            # check task was removed
+            if task not in task.app.tasks:
+                break
             arguments = [] if not task.bind else [task]
             if task.args:
                 arguments.extend(task.args)
