@@ -69,7 +69,8 @@ class TarantoolProcessor(BaseProcessor):
         :return:
         """
         task_workers = [
-            TarantoolTask(loop=self._loop, connection=self._connection, tube=self._queue.tube(queue), foo=foo, args=args,
+            TarantoolTask(loop=self._loop, connection=self._connection, tube=self._queue.tube(queue), foo=foo,
+                          args=args,
                           bind=bind, timeout=timeout, max_retries=max_retries, retry_countdown=retry_countdown,
                           conn_max_retries=self._conn_max_retries, conn_retry_countdown=self._conn_retry_countdown,
                           name=name)
@@ -84,6 +85,10 @@ class TarantoolProcessor(BaseProcessor):
         :return:
         """
         while True:
+            # check task was removed
+            if task not in task.app.tasks:
+                break
+            # check task on retry
             if not task.retries:
                 try:
                     tube_task = await task.tube.take(5)
@@ -98,6 +103,7 @@ class TarantoolProcessor(BaseProcessor):
                         'Tarantool connection problems, trying to reconnect #%d' % (task.conn_retries + 1))
                     task.conn_retries += 1
                     continue
+            # check data was received
             if task.task:
                 arguments = [] if not task.bind else [task]
                 if task.args:
